==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/link/lang/it.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'it', {
	acccessKey: 'Scorciatoia da tastiera',
	advanced: 'Avanzate',
	advisoryContentType: 'Tipo della risorsa collegata',
	advisoryTitle: 'Titolo',
	anchor: {
		toolbar: 'Inserisci/Modifica Ancora',
		menu: 'Proprietà ancora',
		title: 'Proprietà ancora',
		name: 'Nome ancora',
		errorName: 'Inserici il nome dell\'ancora',
		remove: 'Rimuovi l\'ancora'
	},
	anchorId: 'Per id elemento',
	anchorName: 'Per Nome',
	charset: 'Set di caretteri della risorsa collegata',
	cssClasses: 'Nome classe CSS',
	emailAddress: 'Indirizzo E-Mail',
	emailBody: 'Corpo del messaggio',
	emailSubject: 'Oggetto del messaggio',
	id: 'Id',
	info: 'Informazioni collegamento',
	langCode: 'Direzione scrittura',
	langDir: 'Direzione scrittura',
	langDirLTR: 'Da Sinistra a Destra (LTR)',
	langDirRTL: 'Da Destra a Sinistra (RTL)',
	menu: 'Modifica collegamento',
	name: 'Nome',
	noAnchors: '(Nessuna ancora disponibile nel documento)',
	noEmail: 'Devi inserire un\'indirizzo e-mail',
	noUrl: 'Devi inserire l\'URL del collegamento',
	other: '<altro>',
	popupDependent: 'Dipendente (Netscape)',
	popupFeatures: 'Caratteristiche finestra popup',
	popupFullScreen: 'A tutto schermo (IE)',
	popupLeft: 'Posizione da sinistra',
	popupLocationBar: 'Barra degli indirizzi',
	popupMenuBar: 'Barra del menu',
	popupResizable: 'Ridimensionabile',
	popupScrollBars: 'Barre di scorrimento',
	popupStatusBar: 'Barra di stato',
	popupToolbar: 'Barra degli strumenti',
	popupTop: 'Posizione dall\'alto',
	rel: 'Relazioni',
	selectAnchor: 'Scegli Ancora',
	styles: 'Stile',
	tabIndex: 'Ordine di tabulazione',
	target: 'Destinazione',
	targetFrame: '<riquadro>',
	targetFrameName: 'Nome del riquadro di destinazione',
	targetPopup: '<finestra popup>',
	targetPopupName: 'Nome finestra popup',
	title: 'Collegamento',
	toAnchor: 'Ancora nel testo',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toolbar: 'Collegamento',
	type: 'Tipo di Collegamento',
	unlink: 'Elimina collegamento',
	upload: 'Carica'
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/link/lang/it.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'it', {
	acccessKey: 'Scorciatoia da tastiera',
	advanced: 'Avanzate',
	advisoryContentType: 'Tipo della risorsa collegata',
	advisoryTitle: 'Titolo',
	anchor: {
		toolbar: 'Inserisci/Modifica Ancora',
		menu: 'Proprietà ancora',
		title: 'Proprietà ancora',
		name: 'Nome ancora',
		errorName: 'Inserici il nome dell\'ancora',
		remove: 'Rimuovi l\'ancora'
	},
	anchorId: 'Per id elemento',
	anchorName: 'Per Nome',
	charset: 'Set di caretteri della risorsa collegata',
	cssClasses: 'Nome classe CSS',
	download: 'Forza scaricamento',
	displayText: 'Mostra testo',
	emailAddress: 'Indirizzo E-Mail',
	emailBody: 'Corpo del messaggio',
	emailSubject: 'Oggetto del messaggio',
	id: 'Id',
	info: 'Informazioni collegamento',
	langCode: 'Direzione scrittura',
	langDir: 'Direzione scrittura',
	langDirLTR: 'Da Sinistra a Destra (LTR)',
	langDirRTL: 'Da Destra a Sinistra (RTL)',
	menu: 'Modifica collegamento',
	name: 'Nome',
	noAnchors: '(Nessuna ancora disponibile nel documento)',
	noEmail: 'Devi inserire un\'indirizzo e-mail',
	noUrl: 'Devi inserire l\'URL del collegamento',
	noTel: 'Please type the phone number', // MISSING
	other: '<altro>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dipendente (Netscape)',
	popupFeatures: 'Caratteristiche finestra popup',
	popupFullScreen: 'A tutto schermo (IE)',
	popupLeft: 'Posizione da sinistra',
	popupLocationBar: 'Barra degli indirizzi',
	popupMenuBar: 'Barra del menu',
	popupResizable: 'Ridimensionabile',
	popupScrollBars: 'Barre di scorrimento',
	popupStatusBar: 'Barra di stato',
	popupToolbar: 'Barra degli strumenti',
	popupTop: 'Posizione dall\'alto',
	rel: 'Relazioni',
	selectAnchor: 'Scegli Ancora',
	styles: 'Stile',
	tabIndex: 'Ordine di tabulazione',
	target: 'Destinazione',
	targetFrame: '<riquadro>',
	targetFrameName: 'Nome del riquadro di destinazione',
	targetPopup: '<finestra popup>',
	targetPopupName: 'Nome finestra popup',
	title: 'Collegamento',
	toAnchor: 'Ancora nel testo',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Collegamento',
	type: 'Tipo di Collegamento',
	unlink: 'Elimina collegamento',
	upload: 'Carica'
} );
